==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/streambrowser/translations/streambrowser_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>EditStreamDialog</name>
    <message>
        <location filename="../editstreamdialog.ui" line="14"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="34"/>
        <source>URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="44"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="54"/>
        <source>Genre:</source>
        <translation>Είδος:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="64"/>
        <source>Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="74"/>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
</context>
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Add Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation>Πρόσθετο περιηγητή ροών</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation>Σχετικά με το πρόσθετο περιηγητή ροών</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Qmmp πρόσθετο περιηγητή ροών</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Αυτό το πρόσθετο επιτρέπει την προσθήκη μιας ροής από τον κατάλογο ροών του IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Περιηγητής ροών</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Φίλτρο:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Προτιμώμενοι</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Ενημέρωση</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="56"/>
        <location filename="../streamwindow.cpp" line="74"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="57"/>
        <location filename="../streamwindow.cpp" line="75"/>
        <source>Genre</source>
        <translation>Είδος</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="58"/>
        <location filename="../streamwindow.cpp" line="76"/>
        <source>Bitrate</source>
        <translation>Ρυθμός bit</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="59"/>
        <location filename="../streamwindow.cpp" line="77"/>
        <source>Format</source>
        <translation>Μορφή</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="132"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Προσθήκη στα προτιμώμενα</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="135"/>
        <source>&amp;Add to playlist</source>
        <translation>Προσθήκη στη &amp;λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="138"/>
        <source>&amp;Create</source>
        <translation>&amp;Δημιουργία</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="143"/>
        <source>&amp;Remove</source>
        <translation>&amp;Αφαίρεση</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="153"/>
        <source>Done</source>
        <translation>Έγινε</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="156"/>
        <location filename="../streamwindow.cpp" line="157"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="176"/>
        <source>Receiving</source>
        <translation>Γίνεται λήψη</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="273"/>
        <source>Edit Stream</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.3.4.orig.tar.bz2: qmmp-1.3.4/src/plugins/General/streambrowser/translations/streambrowser_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>EditStreamDialog</name>
    <message>
        <location filename="../editstreamdialog.ui" line="14"/>
        <source>Edit Stream</source>
        <translation>Επεξεργασία ροής</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="34"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="44"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="54"/>
        <source>Genre:</source>
        <translation>Είδος:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="64"/>
        <source>Bitrate:</source>
        <translation>Ρυθμός bit:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="74"/>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
</context>
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Add Stream</source>
        <translation>Προσθήκη ροής</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation>Πρόσθετο περιηγητή ροών</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation>Σχετικά με το πρόσθετο περιηγητή ροών</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Qmmp πρόσθετο περιηγητή ροών</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Αυτό το πρόσθετο επιτρέπει την προσθήκη μιας ροής από τον κατάλογο ροών του IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Περιηγητής ροών</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Φίλτρο:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Προτιμώμενοι</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Ενημέρωση</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="56"/>
        <location filename="../streamwindow.cpp" line="74"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="57"/>
        <location filename="../streamwindow.cpp" line="75"/>
        <source>Genre</source>
        <translation>Είδος</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="58"/>
        <location filename="../streamwindow.cpp" line="76"/>
        <source>Bitrate</source>
        <translation>Ρυθμός bit</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="59"/>
        <location filename="../streamwindow.cpp" line="77"/>
        <source>Format</source>
        <translation>Μορφή</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="132"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Προσθήκη στα προτιμώμενα</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="135"/>
        <source>&amp;Add to playlist</source>
        <translation>Προσθήκη στη &amp;λίστα αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="138"/>
        <source>&amp;Create</source>
        <translation>&amp;Δημιουργία</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="143"/>
        <source>&amp;Remove</source>
        <translation>&amp;Αφαίρεση</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="153"/>
        <source>Done</source>
        <translation>Έγινε</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="156"/>
        <location filename="../streamwindow.cpp" line="157"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="176"/>
        <source>Receiving</source>
        <translation>Γίνεται λήψη</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="273"/>
        <source>Edit Stream</source>
        <translation>Επεξεργασία ροής</translation>
    </message>
</context>
</TS>
